@@ -77,6 +77,11 @@ RSet::operator=(const RSet &other)
     internal = other.internal;
 }
 
+RSet::RSet(RSet &&) = default;
+
+RSet&
+RSet::operator=(RSet &&) = default;
+
 RSet::~RSet()
 {
 }
@@ -174,6 +179,11 @@ MSet::operator=(const MSet &other)
     return *this;
 }
 
+MSet::MSet(MSet&&) = default;
+
+MSet&
+MSet::operator=(MSet&&) = default;
+
 void
 MSet::fetch_(Xapian::doccount first, Xapian::doccount last) const
 {
@@ -504,6 +514,16 @@ MSetIterator::get_collapse_count() const
     return mset.internal->items[index].collapse_count;
 }
 
+string
+MSetIterator::get_sort_key() const
+{
+    Assert(mset.internal.get());
+    Xapian::doccount size = mset.internal->items.size();
+    Xapian::doccount index = size - off_from_end;
+    AssertRel(index,<,size);
+    return mset.internal->items[index].sort_key;
+}
+
 string
 MSetIterator::get_description() const
 {
@@ -562,9 +582,9 @@ Enquire::Internal::get_mset(Xapian::doccount first, Xapian::doccount maxitems,
     {
 	Xapian::doccount docs = db.get_doccount();
 	first = min(first, docs);
-	maxitems = min(maxitems, docs);
+	maxitems = min(maxitems, docs - first);
 	check_at_least = min(check_at_least, docs);
-	check_at_least = max(check_at_least, maxitems);
+	check_at_least = max(check_at_least, first + maxitems);
     }
 
     AutoPtr<Xapian::Weight::Internal> stats(new Xapian::Weight::Internal);
@@ -775,6 +795,11 @@ Enquire::operator=(const Enquire & other)
     internal = other.internal;
 }
 
+Enquire::Enquire(Enquire&&) = default;
+
+Enquire&
+Enquire::operator=(Enquire&&) = default;
+
 Enquire::Enquire(const Database &databases)
     : internal(new Internal(databases))
 {
