@@ -780,8 +780,8 @@ QueryTerm::gather_terms(void * void_terms) const
 {
     // Skip Xapian::Query::MatchAll (aka Xapian::Query("")).
     if (!term.empty()) {
-	vector<pair<Xapian::termpos, string> > &terms =
-	    *static_cast<vector<pair<Xapian::termpos, string> >*>(void_terms);
+	vector<pair<Xapian::termpos, string>> &terms =
+	    *static_cast<vector<pair<Xapian::termpos, string>>*>(void_terms);
 	terms.push_back(make_pair(pos, term));
     }
 }
@@ -1049,7 +1049,11 @@ QueryWildcard::postlist(QueryOptimiser * qopt, double factor) const
 
     // We build an OP_OR tree for OP_SYNONYM and then wrap it in a
     // SynonymPostList, which supplies the weights.
-    RETURN(qopt->make_synonym_postlist(pl, factor));
+    //
+    // We know the subqueries from a wildcard expansion are wdf-disjoint
+    // (i.e. each wdf from the document contributes at most itself to the
+    // wdf of the subquery).
+    RETURN(qopt->make_synonym_postlist(pl, factor, true));
 }
 
 termcount
@@ -1258,7 +1262,9 @@ QueryBranch::do_synonym(QueryOptimiser * qopt, double factor) const
 
     // We build an OP_OR tree for OP_SYNONYM and then wrap it in a
     // SynonymPostList, which supplies the weights.
-    RETURN(qopt->make_synonym_postlist(pl, factor));
+    //
+    // FIXME: Detect if the subquery is wdf-disjoint?
+    RETURN(qopt->make_synonym_postlist(pl, factor, false));
 }
 
 PostList *
@@ -1737,16 +1743,21 @@ QuerySynonym::done()
     // subqueries which are MatchNothing.
     if (subqueries.empty())
 	return NULL;
-    // Synonym of a single subquery should only be simplified if that subquery
-    // is a term (or MatchAll), or if it's also OP_SYNONYM.  Note that
-    // MatchNothing subqueries are dropped, so we'd never get here with a
-    // single MatchNothing subquery.
     if (subqueries.size() == 1) {
 	Query::op sub_type = subqueries[0].get_type();
+	// Synonym of a single subquery should only be simplified if that
+	// subquery is a term (or MatchAll), or if it's also OP_SYNONYM.  Note
+	// that MatchNothing subqueries are dropped, so we'd never get here
+	// with a single MatchNothing subquery.
 	if (sub_type == Query::LEAF_TERM || sub_type == Query::LEAF_MATCH_ALL ||
 	    sub_type == Query::OP_SYNONYM) {
 	    return subqueries[0].internal.get();
 	}
+	if (sub_type == Query::OP_WILDCARD) {
+	    auto q = static_cast<QueryWildcard*>(subqueries[0].internal.get());
+	    // SYNONYM over WILDCARD X -> WILDCARD SYNONYM for any combiner X.
+	    return q->change_combiner(Query::OP_SYNONYM);
+	}
     }
     return this;
 }
