@@ -63,12 +63,12 @@
 #include "stringutils.h"
 #include "backends/valuestats.h"
 
-#include "safeerrno.h"
 #include "safesysstat.h"
 #include <sys/types.h>
 
 #include <algorithm>
 #include "autoptr.h"
+#include <cerrno>
 #include <cstdlib>
 #include <string>
 
