@@ -50,6 +50,7 @@
 #include "glass_values.h"
 #include "debuglog.h"
 #include "fd.h"
+#include "filetests.h"
 #include "io_utils.h"
 #include "pack.h"
 #include "net/remoteconnection.h"
@@ -61,12 +62,12 @@
 #include "stringutils.h"
 #include "backends/valuestats.h"
 
-#include "safeerrno.h"
 #include "safesysstat.h"
 #include <sys/types.h>
 
 #include <algorithm>
 #include "autoptr.h"
+#include <cerrno>
 #include <cstdlib>
 #include <string>
 
@@ -125,20 +126,16 @@ GlassDatabase::GlassDatabase(const string &glass_dir, int flags,
 
     int action = flags & Xapian::DB_ACTION_MASK_;
     if (action != Xapian::DB_OPEN && !database_exists()) {
-
 	// Create the directory for the database, if it doesn't exist
 	// already.
-	bool fail = false;
-	struct stat statbuf;
-	if (stat(db_dir.c_str(), &statbuf) == 0) {
-	    if (!S_ISDIR(statbuf.st_mode)) fail = true;
-	} else if (errno != ENOENT || mkdir(db_dir.c_str(), 0755) == -1) {
-	    fail = true;
-	}
-	if (fail) {
-	    throw Xapian::DatabaseCreateError("Cannot create directory '" +
-					      db_dir + "'", errno);
+	if (mkdir(db_dir.c_str(), 0755) < 0) {
+	    int mkdir_errno = errno;
+	    if (mkdir_errno != EEXIST || !dir_exists(db_dir)) {
+		throw Xapian::DatabaseCreateError(db_dir + ": mkdir failed",
+						  mkdir_errno);
+	    }
 	}
+
 	get_database_write_lock(flags, true);
 
 	create_and_open_tables(flags, block_size);
@@ -173,7 +170,7 @@ GlassDatabase::GlassDatabase(int fd)
 	  synonym_table(fd, version_file.get_offset(), readonly),
 	  spelling_table(fd, version_file.get_offset(), readonly),
 	  docdata_table(fd, version_file.get_offset(), readonly),
-	  lock(string()),
+	  lock(),
 	  changes(string())
 {
     LOGCALL_CTOR(DB, "GlassDatabase", fd);
@@ -438,7 +435,7 @@ void
 GlassDatabase::send_whole_database(RemoteConnection & conn, double end_time)
 {
     LOGCALL_VOID(DB, "GlassDatabase::send_whole_database", conn | end_time);
-
+#ifdef XAPIAN_HAS_REMOTE_BACKEND
     // Send the current revision number in the header.
     string buf;
     string uuid = get_uuid();
@@ -470,6 +467,10 @@ GlassDatabase::send_whole_database(RemoteConnection & conn, double end_time)
 	}
 	p += len + 1;
     } while (*p);
+#else
+    (void)conn;
+    (void)end_time;
+#endif
 }
 
 void
@@ -479,7 +480,7 @@ GlassDatabase::write_changesets_to_fd(int fd,
 				      ReplicationInfo * info)
 {
     LOGCALL_VOID(DB, "GlassDatabase::write_changesets_to_fd", fd | revision | need_whole_db | info);
-
+#ifdef XAPIAN_HAS_REMOTE_BACKEND
     int whole_db_copies_left = MAX_DB_COPIES_PER_CONVERSATION;
     glass_revision_number_t start_rev_num = 0;
     string start_uuid = get_uuid();
@@ -595,6 +596,12 @@ GlassDatabase::write_changesets_to_fd(int fd,
 	}
     }
     conn.send_message(REPL_REPLY_END_OF_CHANGES, string(), 0.0);
+#else
+    (void)fd;
+    (void)revision;
+    (void)need_whole_db;
+    (void)info;
+#endif
 }
 
 void
@@ -739,14 +746,7 @@ GlassDatabase::get_unique_terms(Xapian::docid did) const
     LOGCALL(DB, Xapian::termcount, "GlassDatabase::get_unique_terms", did);
     Assert(did != 0);
     intrusive_ptr<const GlassDatabase> ptrtothis(this);
-    GlassTermList termlist(ptrtothis, did);
-    // Note that the "approximate" size should be exact in this case.
-    //
-    // get_unique_terms() really ought to only count terms with wdf > 0, but
-    // that's expensive to calculate on demand, so for now let's just ensure
-    // unique_terms <= doclen.
-    RETURN(min(termlist.get_approx_size(),
-	       postlist_table.get_doclength(did, ptrtothis)));
+    RETURN(GlassTermList(ptrtothis, did).get_unique_terms());
 }
 
 void
@@ -795,9 +795,10 @@ GlassDatabase::get_doclength_upper_bound() const
 Xapian::termcount
 GlassDatabase::get_wdf_upper_bound(const string & term) const
 {
-    Xapian::termcount cf;
-    get_freqs(term, NULL, &cf);
-    return min(cf, version_file.get_wdf_upper_bound());
+    Assert(!term.empty());
+    Xapian::termcount wdfub;
+    postlist_table.get_freqs(term, NULL, NULL, &wdfub);
+    return min(wdfub, version_file.get_wdf_upper_bound());
 }
 
 bool
@@ -998,7 +999,7 @@ GlassDatabase::locked() const
 ///////////////////////////////////////////////////////////////////////////
 
 GlassWritableDatabase::GlassWritableDatabase(const string &dir, int flags,
-					       int block_size)
+					     int block_size)
 	: GlassDatabase(dir, flags, block_size),
 	  change_count(0),
 	  flush_threshold(0),
@@ -1251,7 +1252,13 @@ GlassWritableDatabase::replace_document(Xapian::docid did,
 	    bool pos_modified = !modifying ||
 				document.internal->term_positions_modified();
 	    intrusive_ptr<const GlassWritableDatabase> ptrtothis(this);
-	    GlassTermList termlist(ptrtothis, did);
+	    GlassTermList termlist(ptrtothis, did, false);
+	    // We passed false for throw_if_not_present so check at_end()
+	    // before next() to see if the document isn't present at all.
+	    if (termlist.at_end()) {
+		(void)add_document_(did, document);
+		return;
+	    }
 	    Xapian::TermIterator term = document.termlist_begin();
 	    Xapian::termcount old_doclen = termlist.get_doclength();
 	    version_file.delete_document(old_doclen);
@@ -1339,9 +1346,6 @@ GlassWritableDatabase::replace_document(Xapian::docid did,
 	    // Replace the values.
 	    value_manager.replace_document(did, document, value_stats);
 	}
-    } catch (const Xapian::DocNotFoundError &) {
-	(void)add_document_(did, document);
-	return;
     } catch (...) {
 	// If an error occurs while replacing a document, or doing any other
 	// transaction, the modifications so far must be cleared before
