@@ -27,8 +27,6 @@
 
 #include <xapian/error.h>
 
-#include "safeerrno.h"
-
 #include "omassert.h"
 #include "posixy_wrapper.h"
 #include "str.h"
@@ -36,6 +34,7 @@
 
 #include <sys/types.h>
 
+#include <cerrno>
 #include <cstring>   /* for memmove */
 #include <climits>   /* for CHAR_BIT */
 
@@ -65,8 +64,8 @@ using namespace std;
 #ifdef BTREE_DEBUG_FULL
 /*------debugging aids from here--------*/
 
-static void print_key(const byte * p, int c, int j);
-static void print_tag(const byte * p, int c, int j);
+static void print_key(const uint8_t * p, int c, int j);
+static void print_tag(const uint8_t * p, int c, int j);
 
 /*
 static void report_cursor(int N, Btree * B, Glass::Cursor * C)
@@ -82,9 +81,9 @@ static void report_cursor(int N, Btree * B, Glass::Cursor * C)
 /*------to here--------*/
 #endif /* BTREE_DEBUG_FULL */
 
-static inline byte *zeroed_new(size_t size)
+static inline uint8_t *zeroed_new(size_t size)
 {
-    byte *temp = new byte[size];
+    uint8_t *temp = new uint8_t[size];
     memset(temp, 0, size);
     return temp;
 }
@@ -157,7 +156,7 @@ static inline byte *zeroed_new(size_t size)
 
 /// read_block(n, p) reads block n of the DB file to address p.
 void
-GlassTable::read_block(uint4 n, byte * p) const
+GlassTable::read_block(uint4 n, uint8_t * p) const
 {
     // Log the value of p, not the contents of the block it points to...
     LOGCALL_VOID(DB, "GlassTable::read_block", n | (void*)p);
@@ -188,7 +187,7 @@ GlassTable::read_block(uint4 n, byte * p) const
  *  invalidating any existing revisions, which may be useful information.
  */
 void
-GlassTable::write_block(uint4 n, const byte * p, bool appending) const
+GlassTable::write_block(uint4 n, const uint8_t * p, bool appending) const
 {
     LOGCALL_VOID(DB, "GlassTable::write_block", n | p | appending);
     Assert(writable);
@@ -285,7 +284,6 @@ GlassTable::write_block(uint4 n, const byte * p, bool appending) const
    sense given above, and BC->B is the handle for the B-tree again.
 */
 
-
 void
 GlassTable::set_overwritten() const
 {
@@ -321,11 +319,11 @@ GlassTable::block_to_cursor(Glass::Cursor * C_, int j, uint4 n) const
 
     // Check if the block is in the built-in cursor (potentially in
     // modified form).
-    const byte * p;
+    const uint8_t * p;
     if (n == C[j].get_n()) {
 	p = C_[j].clone(C[j]);
     } else {
-	byte * q = C_[j].init(block_size);
+	uint8_t * q = C_[j].init(block_size);
 	read_block(n, q);
 	p = q;
 	C_[j].set_n(n);
@@ -416,7 +414,7 @@ GlassTable::alter()
 */
 
 int
-GlassTable::find_in_leaf(const byte * p, LeafItem item, int c, bool& exact)
+GlassTable::find_in_leaf(const uint8_t * p, LeafItem item, int c, bool& exact)
 {
     LOGCALL_STATIC(DB, int, "GlassTable::find_in_leaf", (const void*)p | (const void *)item.get_address() | c | Literal("bool&"));
     // c should be odd (either -1, or an even offset from DIR_START).
@@ -467,7 +465,7 @@ GlassTable::find_in_leaf(const byte * p, LeafItem item, int c, bool& exact)
 }
 
 template<typename ITEM> int
-find_in_branch_(const byte * p, ITEM item, int c)
+find_in_branch_(const uint8_t * p, ITEM item, int c)
 {
     // c should be odd (either -1, or an even offset from DIR_START).
     Assert((c & 1) == 1);
@@ -507,14 +505,14 @@ find_in_branch_(const byte * p, ITEM item, int c)
 }
 
 int
-GlassTable::find_in_branch(const byte * p, LeafItem item, int c)
+GlassTable::find_in_branch(const uint8_t * p, LeafItem item, int c)
 {
     LOGCALL_STATIC(DB, int, "GlassTable::find_in_branch", (const void*)p | (const void *)item.get_address() | c);
     RETURN(find_in_branch_(p, item, c));
 }
 
 int
-GlassTable::find_in_branch(const byte * p, BItem item, int c)
+GlassTable::find_in_branch(const uint8_t * p, BItem item, int c)
 {
     LOGCALL_STATIC(DB, int, "GlassTable::find_in_branch", (const void*)p | (const void *)item.get_address() | c);
     RETURN(find_in_branch_(p, item, c));
@@ -532,7 +530,7 @@ GlassTable::find(Glass::Cursor * C_) const
 {
     LOGCALL(DB, bool, "GlassTable::find", (void*)C_);
     // Note: the parameter is needed when we're called by GlassCursor
-    const byte * p;
+    const uint8_t * p;
     int c;
     for (int j = level; j > 0; --j) {
 	p = C_[j].get_p();
@@ -561,13 +559,13 @@ GlassTable::find(Glass::Cursor * C_) const
 */
 
 void
-GlassTable::compact(byte * p)
+GlassTable::compact(uint8_t * p)
 {
     LOGCALL_VOID(DB, "GlassTable::compact", (void*)p);
     Assert(p != buffer);
     Assert(writable);
     int e = block_size;
-    byte * b = buffer;
+    uint8_t * b = buffer;
     int dir_end = DIR_END(p);
     if (GET_LEVEL(p) == 0) {
 	// Leaf.
@@ -610,7 +608,7 @@ GlassTable::split_root(uint4 split_n)
 	throw Xapian::DatabaseCorruptError("Btree has grown impossibly large (" STRINGIZE(BTREE_CURSOR_LEVELS) " levels)");
     }
 
-    byte * q = C[level].init(block_size);
+    uint8_t * q = C[level].init(block_size);
     memset(q, 0, block_size);
     C[level].c = DIR_START;
     C[level].set_n(free_list.get_block(this, block_size));
@@ -621,7 +619,7 @@ GlassTable::split_root(uint4 split_n)
     compact(q);   /* to reset TOTAL_FREE, MAX_FREE */
 
     /* form a null key in b with a pointer to the old root */
-    byte b[10]; /* 7 is exact */
+    uint8_t b[10]; /* 7 is exact */
     BItem_wr item(b);
     item.form_null_key(split_n);
     add_branch_item(item, level);
@@ -672,7 +670,7 @@ GlassTable::enter_key_above_leaf(LeafItem previtem, LeafItem newitem)
     if (i < newkey_len) i++;
 
     // Enough space for a branch item with maximum length key.
-    byte b[BYTES_PER_BLOCK_NUMBER + K1 + 255 + X2];
+    uint8_t b[BYTES_PER_BLOCK_NUMBER + K1 + 255 + X2];
     BItem_wr item(b);
     AssertRel(i, <=, 255);
     item.set_truncated_key_and_block(newkey, new_comp, i, blocknumber);
@@ -713,7 +711,7 @@ GlassTable::enter_key_above_branch(int j, BItem newitem)
     uint4 blocknumber = C[j - 1].get_n();
 
     // Enough space for a branch item with maximum length key.
-    byte b[BYTES_PER_BLOCK_NUMBER + K1 + 255 + X2];
+    uint8_t b[BYTES_PER_BLOCK_NUMBER + K1 + 255 + X2];
     BItem_wr item(b);
     item.set_key_and_block(newitem.key(), blocknumber);
 
@@ -730,7 +728,7 @@ GlassTable::enter_key_above_branch(int j, BItem newitem)
  */
 
 int
-GlassTable::mid_point(byte * p) const
+GlassTable::mid_point(uint8_t * p) const
 {
     LOGCALL(DB, int, "GlassTable::mid_point", (void*)p);
     int n = 0;
@@ -767,7 +765,7 @@ GlassTable::mid_point(byte * p) const
 */
 
 void
-GlassTable::add_item_to_leaf(byte * p, LeafItem kt_, int c)
+GlassTable::add_item_to_leaf(uint8_t * p, LeafItem kt_, int c)
 {
     LOGCALL_VOID(DB, "GlassTable::add_item_to_leaf", (void*)p | Literal("kt_") | c);
     Assert(writable);
@@ -807,7 +805,7 @@ GlassTable::add_item_to_leaf(byte * p, LeafItem kt_, int c)
 */
 
 void
-GlassTable::add_item_to_branch(byte * p, BItem kt_, int c)
+GlassTable::add_item_to_branch(uint8_t * p, BItem kt_, int c)
 {
     LOGCALL_VOID(DB, "GlassTable::add_item_to_branch", (void*)p | Literal("kt_") | c);
     Assert(writable);
@@ -847,7 +845,7 @@ GlassTable::add_leaf_item(LeafItem kt_)
 {
     LOGCALL_VOID(DB, "GlassTable::add_leaf_item", Literal("kt_"));
     Assert(writable);
-    byte * p = C[0].get_modifiable_p(block_size);
+    uint8_t * p = C[0].get_modifiable_p(block_size);
     int c = C[0].c;
     uint4 n;
 
@@ -942,7 +940,7 @@ GlassTable::add_branch_item(BItem kt_, int j)
 {
     LOGCALL_VOID(DB, "GlassTable::add_branch_item", Literal("kt_") | j);
     Assert(writable);
-    byte * p = C[j].get_modifiable_p(block_size);
+    uint8_t * p = C[j].get_modifiable_p(block_size);
     int c = C[j].c;
 
     int needed = kt_.size() + D2;
@@ -1039,7 +1037,7 @@ GlassTable::delete_leaf_item(bool repeatedly)
 {
     LOGCALL_VOID(DB, "GlassTable::delete_leaf_item", repeatedly);
     Assert(writable);
-    byte * p = C[0].get_modifiable_p(block_size);
+    uint8_t * p = C[0].get_modifiable_p(block_size);
     int c = C[0].c;
     AssertRel(DIR_START,<=,c);
     AssertRel(c,<,DIR_END(p));
@@ -1074,7 +1072,7 @@ GlassTable::delete_branch_item(int j)
 {
     LOGCALL_VOID(DB, "GlassTable::delete_branch_item", j);
     Assert(writable);
-    byte * p = C[j].get_modifiable_p(block_size);
+    uint8_t * p = C[j].get_modifiable_p(block_size);
     int c = C[j].c;
     AssertRel(DIR_START,<=,c);
     AssertRel(c,<,DIR_END(p));
@@ -1163,7 +1161,7 @@ GlassTable::add_kt(bool found)
 	seq_count = SEQ_START_POINT;
 	sequential = false;
 
-	byte * p = C[0].get_modifiable_p(block_size);
+	uint8_t * p = C[0].get_modifiable_p(block_size);
 	int c = C[0].c;
 	AssertRel(DIR_START,<=,c);
 	AssertRel(c,<,DIR_END(p));
@@ -1175,7 +1173,7 @@ GlassTable::add_kt(bool found)
 
 	if (needed <= 0) {
 	    /* simple replacement */
-	    memmove(const_cast<byte *>(item.get_address()),
+	    memmove(const_cast<uint8_t *>(item.get_address()),
 		    kt.get_address(), kt_size);
 	    SET_TOTAL_FREE(p, TOTAL_FREE(p) - needed);
 	} else {
@@ -1315,7 +1313,7 @@ GlassTable::add(const string &key, string tag, bool already_compressed)
 	// complicated.
 	first_L = tag_size;
     } else if (!found) {
-	const byte * p = C[0].get_p();
+	const uint8_t * p = C[0].get_p();
 	size_t n = TOTAL_FREE(p) % (max_item_size + D2);
 	if (n > D2 + cd) {
 	    n -= (D2 + cd);
@@ -1451,7 +1449,7 @@ GlassTable::readahead_key(const string &key) const
 
     // We'll only readahead the first level, since descending the B-tree would
     // require actual reads that would likely hurt performance more than help.
-    const byte * p = C[level].get_p();
+    const uint8_t * p = C[level].get_p();
     int c = find_in_branch(p, kt, C[level].c);
     uint4 n = BItem(p, c).block_given_by();
     // Don't preread if it's the block we last preread or already in the
@@ -1611,7 +1609,7 @@ GlassTable::read_root()
     LOGCALL_VOID(DB, "GlassTable::read_root", NO_ARGS);
     if (faked_root_block) {
 	/* root block for an unmodified database. */
-	byte * p = C[0].init(block_size);
+	uint8_t * p = C[0].init(block_size);
 	Assert(p);
 
 	/* clear block - shouldn't be necessary, but is a bit nicer,
@@ -1681,7 +1679,7 @@ GlassTable::do_open_to_write(const RootInfo * root_info,
     writable = true;
     basic_open(root_info, rev);
 
-    split_p = new byte[block_size];
+    split_p = new uint8_t[block_size];
 
     buffer = zeroed_new(block_size);
 
@@ -2029,7 +2027,7 @@ GlassTable::prev_for_sequential(Glass::Cursor * C_, int /*dummy*/) const
     AssertRel(c,<,DIR_END(C_[0].get_p()));
     if (c == DIR_START) {
 	uint4 n = C_[0].get_n();
-	const byte * p;
+	const uint8_t * p;
 	while (true) {
 	    if (n == 0) RETURN(false);
 	    n--;
@@ -2054,7 +2052,7 @@ GlassTable::prev_for_sequential(Glass::Cursor * C_, int /*dummy*/) const
 		// Block isn't in the built-in cursor, so the form on disk
 		// is valid, so read it to check if it's the next level 0
 		// block.
-		byte * q = C_[0].init(block_size);
+		uint8_t * q = C_[0].init(block_size);
 		read_block(n, q);
 		p = q;
 		C_[0].set_n(n);
@@ -2077,7 +2075,7 @@ bool
 GlassTable::next_for_sequential(Glass::Cursor * C_, int /*dummy*/) const
 {
     LOGCALL(DB, bool, "GlassTable::next_for_sequential", Literal("C_") | Literal("/*dummy*/"));
-    const byte * p = C_[0].get_p();
+    const uint8_t * p = C_[0].get_p();
     Assert(p);
     int c = C_[0].c;
     AssertRel(c,<,DIR_END(p));
@@ -2108,12 +2106,12 @@ GlassTable::next_for_sequential(Glass::Cursor * C_, int /*dummy*/) const
 		    // Block isn't in the built-in cursor, so the form on disk
 		    // is valid, so read it to check if it's the next level 0
 		    // block.
-		    byte * q = C_[0].init(block_size);
+		    uint8_t * q = C_[0].init(block_size);
 		    read_block(n, q);
 		    p = q;
 		}
 	    } else {
-		byte * q = C_[0].init(block_size);
+		uint8_t * q = C_[0].init(block_size);
 		read_block(n, q);
 		p = q;
 	    }
@@ -2134,7 +2132,7 @@ bool
 GlassTable::prev_default(Glass::Cursor * C_, int j) const
 {
     LOGCALL(DB, bool, "GlassTable::prev_default", Literal("C_") | j);
-    const byte * p = C_[j].get_p();
+    const uint8_t * p = C_[j].get_p();
     int c = C_[j].c;
     AssertRel(DIR_START,<=,c);
     AssertRel(c,<,DIR_END(p));
@@ -2158,7 +2156,7 @@ bool
 GlassTable::next_default(Glass::Cursor * C_, int j) const
 {
     LOGCALL(DB, bool, "GlassTable::next_default", Literal("C_") | j);
-    const byte * p = C_[j].get_p();
+    const uint8_t * p = C_[j].get_p();
     int c = C_[j].c;
     AssertRel(c,<,DIR_END(p));
     AssertRel((unsigned)DIR_END(p),<=,block_size);
