@@ -1,7 +1,7 @@
 /** @file glass_version.h
  * @brief GlassVersion class
  */
-/* Copyright (C) 2006,2007,2008,2009,2010,2013,2014,2015,2016 Olly Betts
+/* Copyright (C) 2006,2007,2008,2009,2010,2013,2014,2015,2016,2018 Olly Betts
  * Copyright (C) 2011 Dan Colish
  *
  * This program is free software; you can redistribute it and/or modify
@@ -30,7 +30,7 @@
 #include <cstring>
 #include <string>
 
-#include "common/safeuuid.h"
+#include "backends/uuids.h"
 #include "internaltypes.h"
 #include "xapian/types.h"
 
@@ -95,11 +95,8 @@ class GlassVersion {
     RootInfo root[Glass::MAX_];
     RootInfo old_root[Glass::MAX_];
 
-    /** The UUID of this database.
-     *
-     *  This is mutable for older uuid libraries which take non-const uuid_t.
-     */
-    mutable uuid_t uuid;
+    /// The UUID of this database.
+    Uuid uuid;
 
     /** File descriptor.
      *
@@ -197,32 +194,14 @@ class GlassVersion {
 
     /// Return pointer to 16 byte UUID.
     const char * get_uuid() const {
-	// uuid is unsigned char[].
-	return reinterpret_cast<const char *>(uuid);
+	return uuid.data();
     }
 
     /// Return UUID in the standard 36 character string format.
     std::string get_uuid_string() const {
-	char buf[37];
-	uuid_unparse_lower(uuid, buf);
-	return std::string(buf, 36);
+	return uuid.to_string();
     }
 
-#if 0 // Unused currently.
-    /// Set the UUID from 16 byte binary value @a data.
-    void set_uuid(const void * data) {
-	std::memcpy(uuid, data, 16);
-    }
-
-    /** Set the UUID from the standard 36 character string format.
-     *
-     *  @return true if @a s was successfully parsed; false otherwise.
-     */
-    bool set_uuid_string(const std::string & s) {
-	return uuid_parse(s.c_str(), uuid);
-    }
-#endif
-
     Xapian::doccount get_doccount() const { return doccount; }
 
     Xapian::totallength get_total_doclen() const { return total_doclen; }
