@@ -1,7 +1,7 @@
 /** @file pack.h
  * @brief Pack types into strings and unpack them again.
  */
-/* Copyright (C) 2009,2015,2016 Olly Betts
+/* Copyright (C) 2009,2015,2016,2017 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
 
 #include <cstring>
 #include <string>
+#include <type_traits>
 
 #include "omassert.h"
 
@@ -87,8 +88,7 @@ template<class U>
 inline void
 pack_uint_last(std::string & s, U value)
 {
-    // Check U is an unsigned type.
-    STATIC_ASSERT_UNSIGNED_TYPE(U);
+    static_assert(std::is_unsigned<U>::value, "Unsigned type required");
 
     while (value) {
 	s += char(value & 0xff);
@@ -106,8 +106,7 @@ template<class U>
 inline bool
 unpack_uint_last(const char ** p, const char * end, U * result)
 {
-    // Check U is an unsigned type.
-    STATIC_ASSERT_UNSIGNED_TYPE(U);
+    static_assert(std::is_unsigned<U>::value, "Unsigned type required");
     Assert(result);
 
     const char * ptr = *p;
@@ -145,8 +144,7 @@ template<class U>
 inline void
 C_pack_uint_preserving_sort(std::string & s, U value)
 {
-    // Check U is an unsigned type.
-    STATIC_ASSERT_UNSIGNED_TYPE(U);
+    static_assert(std::is_unsigned<U>::value, "Unsigned type required");
 #if 0
     // FIXME: Doesn't work with 64-bit Xapian::docid, etc.
     static_assert(sizeof(U) <= SORTABLE_UINT_MAX_BYTES,
@@ -182,8 +180,7 @@ template<class U>
 inline bool
 C_unpack_uint_preserving_sort(const char ** p, const char * end, U * result)
 {
-    // Check U is an unsigned type.
-    STATIC_ASSERT_UNSIGNED_TYPE(U);
+    static_assert(std::is_unsigned<U>::value, "Unsigned type required");
     static_assert(sizeof(U) < 256,
 		  "Template type U too wide for database format");
     Assert(result);
@@ -221,11 +218,30 @@ C_unpack_uint_preserving_sort(const char ** p, const char * end, U * result)
 #if HAVE_DECL___BUILTIN_CLZ && \
     HAVE_DECL___BUILTIN_CLZL && \
     HAVE_DECL___BUILTIN_CLZLL
-inline int do_clz(unsigned value) { return __builtin_clz(value); }
+template<typename T>
+inline int
+do_clz(T value) {
+    extern int no_clz_builtin_for_this_type(T);
+    return no_clz_builtin_for_this_type(value);
+}
 
-inline int do_clz(unsigned long value) { return __builtin_clzl(value); }
+template<>
+inline int
+do_clz(unsigned value) {
+    return __builtin_clz(value);
+}
 
-inline int do_clz(unsigned long long value) { return __builtin_clzll(value); }
+template<>
+inline int
+do_clz(unsigned long value) {
+    return __builtin_clzl(value);
+}
+
+template<>
+inline int
+do_clz(unsigned long long value) {
+    return __builtin_clzll(value);
+}
 
 # define HAVE_DO_CLZ
 #endif
@@ -248,8 +264,7 @@ template<class U>
 inline void
 pack_uint_preserving_sort(std::string & s, U value)
 {
-    // Check U is an unsigned type.
-    STATIC_ASSERT_UNSIGNED_TYPE(U);
+    static_assert(std::is_unsigned<U>::value, "Unsigned type required");
     static_assert(sizeof(U) <= 8,
 		  "Template type U too wide for database format");
     // The clz() functions are undefined for 0, so handle the smallest band
@@ -298,8 +313,7 @@ template<class U>
 inline bool
 unpack_uint_preserving_sort(const char ** p, const char * end, U * result)
 {
-    // Check U is an unsigned type.
-    STATIC_ASSERT_UNSIGNED_TYPE(U);
+    static_assert(std::is_unsigned<U>::value, "Unsigned type required");
     static_assert(sizeof(U) <= 8,
 		  "Template type U too wide for database format");
     Assert(result);
@@ -363,8 +377,7 @@ template<class U>
 inline void
 pack_uint(std::string & s, U value)
 {
-    // Check U is an unsigned type.
-    STATIC_ASSERT_UNSIGNED_TYPE(U);
+    static_assert(std::is_unsigned<U>::value, "Unsigned type required");
 
     while (value >= 128) {
 	s += static_cast<char>(static_cast<unsigned char>(value) | 0x80);
@@ -395,8 +408,7 @@ template<class U>
 inline bool
 unpack_uint(const char ** p, const char * end, U * result)
 {
-    // Check U is an unsigned type.
-    STATIC_ASSERT_UNSIGNED_TYPE(U);
+    static_assert(std::is_unsigned<U>::value, "Unsigned type required");
 
     const char * ptr = *p;
     Assert(ptr);
