@@ -22,7 +22,6 @@
 
 #include <config.h>
 
-#include "safeerrno.h"
 #include "safefcntl.h"
 
 #include "progclient.h"
@@ -30,12 +29,13 @@
 #include "closefrom.h"
 #include "debuglog.h"
 
+#include <cerrno>
 #include <string>
 #include <vector>
 
 #include <sys/types.h>
 #ifndef __WIN32__
-# include <sys/socket.h>
+# include "safesyssocket.h"
 # include <sys/wait.h>
 #else
 # include <cstdio> // For sprintf().
@@ -64,15 +64,16 @@ split_words(const string &text, vector<string> &words, char ws = ' ')
 #endif
 
 ProgClient::ProgClient(const string &progname, const string &args,
-		       double timeout_, bool writable)
+		       double timeout_, bool writable, int flags)
 	: RemoteDatabase(run_program(progname, args
 #ifndef __WIN32__
 						   , pid
 #endif
-        ),
-			 timeout_, get_progcontext(progname, args), writable)
+	),
+			 timeout_, get_progcontext(progname, args), writable,
+			 flags)
 {
-    LOGCALL_VOID(DB, "ProgClient::ProgClient", progname | args | timeout_ | writable);
+    LOGCALL_CTOR(DB, "ProgClient", progname | args | timeout_ | writable | flags);
 }
 
 string
@@ -96,7 +97,7 @@ ProgClient::run_program(const string &progname, const string &args
      */
     int sv[2];
 
-    if (socketpair(PF_UNIX, SOCK_STREAM, 0, sv) < 0) {
+    if (socketpair(PF_UNIX, SOCK_STREAM|SOCK_CLOEXEC, 0, sv) < 0) {
 	throw Xapian::NetworkError(string("socketpair failed"), get_progcontext(progname, args), errno);
     }
 
@@ -117,6 +118,19 @@ ProgClient::run_program(const string &progname, const string &args
      *   set up file descriptors and exec program
      */
 
+#if defined F_SETFD && defined FD_CLOEXEC
+    // Clear close-on-exec flag, if we set it when we called socketpair().
+    // Clearing it here means there's no window where another thread in the
+    // parent process could fork()+exec() and end up with this fd still
+    // open (assuming close-on-exec is supported).
+    //
+    // We can't use a preprocessor check on the *value* of SOCK_CLOEXEC as
+    // on Linux SOCK_CLOEXEC is an enum, with '#define SOCK_CLOEXEC
+    // SOCK_CLOEXEC' to allow '#ifdef SOCK_CLOEXEC' to work.
+    if (SOCK_CLOEXEC != 0)
+	(void)fcntl(sv[1], F_SETFD, 0);
+#endif
+
     // replace stdin and stdout with the socket
     // FIXME: check return values from dup2.
     if (sv[1] != 0) {
@@ -158,7 +172,7 @@ ProgClient::run_program(const string &progname, const string &args
     /* throwing an exception is a bad idea, since we're
      * not the original process. */
     _exit(-1);
-#if defined __sgi || defined __xlC__
+#ifdef __xlC__
     // Avoid "missing return statement" warning.
     return 0;
 #endif
@@ -168,8 +182,8 @@ ProgClient::run_program(const string &progname, const string &args
     static unsigned int pipecount = 0;
     char pipename[256];
     sprintf(pipename, "\\\\.\\pipe\\xapian-remote-%lx-%lx-%x",
-	    (unsigned long)GetCurrentProcessId(),
-	    (unsigned long)GetCurrentThreadId(), pipecount++);
+	    static_cast<unsigned long>(GetCurrentProcessId()),
+	    static_cast<unsigned long>(GetCurrentThreadId()), pipecount++);
     // Create a pipe so we can read stdout from the child process.
     HANDLE hPipe = CreateNamedPipe(pipename,
 				   PIPE_ACCESS_DUPLEX|FILE_FLAG_OVERLAPPED,
@@ -180,7 +194,7 @@ ProgClient::run_program(const string &progname, const string &args
     if (hPipe == INVALID_HANDLE_VALUE) {
 	throw Xapian::NetworkError("CreateNamedPipe failed",
 				   get_progcontext(progname, args),
-				   -(int)GetLastError());
+				   -int(GetLastError()));
     }
 
     HANDLE hClient = CreateFile(pipename,
@@ -190,13 +204,13 @@ ProgClient::run_program(const string &progname, const string &args
     if (hClient == INVALID_HANDLE_VALUE) {
 	throw Xapian::NetworkError("CreateFile failed",
 				   get_progcontext(progname, args),
-				   -(int)GetLastError());
+				   -int(GetLastError()));
     }
 
     if (!ConnectNamedPipe(hPipe, NULL) && GetLastError() != ERROR_PIPE_CONNECTED) {
 	throw Xapian::NetworkError("ConnectNamedPipe failed",
 				   get_progcontext(progname, args),
-				   -(int)GetLastError());
+				   -int(GetLastError()));
     }
 
     // Set the appropriate handles to be inherited by the child process.
@@ -222,12 +236,12 @@ ProgClient::run_program(const string &progname, const string &args
     if (!ok) {
 	throw Xapian::NetworkError("CreateProcess failed",
 				   get_progcontext(progname, args),
-				   -(int)GetLastError());
+				   -int(GetLastError()));
     }
 
     CloseHandle(hClient);
     CloseHandle(procinfo.hThread);
-    RETURN(_open_osfhandle((intptr_t)hPipe, O_RDWR|O_BINARY));
+    RETURN(_open_osfhandle(intptr_t(hPipe), O_RDWR|O_BINARY));
 #endif
 }
 
