@@ -1,7 +1,7 @@
 /** @file termgenerator_internal.cc
  * @brief TermGenerator class internals
  */
-/* Copyright (C) 2007,2010,2011,2012,2015,2016,2017 Olly Betts
+/* Copyright (C) 2007,2010,2011,2012,2015,2016,2017,2018 Olly Betts
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -47,17 +47,20 @@ using namespace std;
 
 namespace Xapian {
 
-inline bool
-U_isupper(unsigned ch) {
+static inline bool
+U_isupper(unsigned ch)
+{
     return (ch < 128 && C_isupper(static_cast<unsigned char>(ch)));
 }
 
-inline unsigned check_wordchar(unsigned ch) {
+static inline unsigned
+check_wordchar(unsigned ch)
+{
     if (Unicode::is_wordchar(ch)) return Unicode::tolower(ch);
     return 0;
 }
 
-inline bool
+static inline bool
 should_stem(const std::string & term)
 {
     const unsigned int SHOULD_STEM_MASK =
@@ -72,9 +75,11 @@ should_stem(const std::string & term)
 /** Value representing "ignore this" when returned by check_infix() or
  *  check_infix_digit().
  */
-const unsigned UNICODE_IGNORE = numeric_limits<unsigned>::max();
+static const unsigned UNICODE_IGNORE = numeric_limits<unsigned>::max();
 
-inline unsigned check_infix(unsigned ch) {
+static inline unsigned
+check_infix(unsigned ch)
+{
     if (ch == '\'' || ch == '&' || ch == 0xb7 || ch == 0x5f4 || ch == 0x2027) {
 	// Unicode includes all these except '&' in its word boundary rules,
 	// as well as 0x2019 (which we handle below) and ':' (for Swedish
@@ -90,7 +95,9 @@ inline unsigned check_infix(unsigned ch) {
     return 0;
 }
 
-inline unsigned check_infix_digit(unsigned ch) {
+static inline unsigned
+check_infix_digit(unsigned ch)
+{
     // This list of characters comes from Unicode's word identifying algorithm.
     switch (ch) {
 	case ',':
@@ -111,12 +118,14 @@ inline unsigned check_infix_digit(unsigned ch) {
     return 0;
 }
 
-inline bool
+static inline bool
 is_digit(unsigned ch) {
     return (Unicode::get_category(ch) == Unicode::DECIMAL_DIGIT_NUMBER);
 }
 
-inline unsigned check_suffix(unsigned ch) {
+static inline unsigned
+check_suffix(unsigned ch)
+{
     if (ch == '+' || ch == '#') return ch;
     // FIXME: what about '-'?
     return 0;
@@ -128,7 +137,8 @@ inline unsigned check_suffix(unsigned ch) {
  *  std::string holding the term, and positional is a bool indicating
  *  if this term carries positional information.
  */
-template<typename ACTION> void
+template<typename ACTION>
+static void
 parse_terms(Utf8Iterator itor, bool cjk_ngram, bool with_positions, ACTION action)
 {
     while (true) {
@@ -253,9 +263,10 @@ TermGenerator::Internal::index_text(Utf8Iterator itor, termcount wdf_inc,
 		return true;
 
 	    if (strategy == TermGenerator::STEM_SOME ||
-		strategy == TermGenerator::STEM_NONE) {
+		strategy == TermGenerator::STEM_NONE ||
+		strategy == TermGenerator::STEM_SOME_FULL_POS) {
 		if (positional) {
-		    doc.add_posting(prefix + term, ++termpos, wdf_inc);
+		    doc.add_posting(prefix + term, ++cur_pos, wdf_inc);
 		} else {
 		    doc.add_term(prefix + term, wdf_inc);
 		}
@@ -269,7 +280,8 @@ TermGenerator::Internal::index_text(Utf8Iterator itor, termcount wdf_inc,
 	    if (strategy == TermGenerator::STEM_NONE ||
 		!stemmer.internal.get()) return true;
 
-	    if (strategy == TermGenerator::STEM_SOME) {
+	    if (strategy == TermGenerator::STEM_SOME ||
+		strategy == TermGenerator::STEM_SOME_FULL_POS) {
 		if (current_stop_mode == TermGenerator::STOP_STEMMED &&
 		    (*stopper)(term))
 		    return true;
@@ -289,7 +301,8 @@ TermGenerator::Internal::index_text(Utf8Iterator itor, termcount wdf_inc,
 	    stemmed_term += prefix;
 	    stemmed_term += stem;
 	    if (strategy != TermGenerator::STEM_SOME && with_positions) {
-		doc.add_posting(stemmed_term, ++termpos, wdf_inc);
+		if (strategy != TermGenerator::STEM_SOME_FULL_POS) ++cur_pos;
+		doc.add_posting(stemmed_term, cur_pos, wdf_inc);
 	    } else {
 		doc.add_term(stemmed_term, wdf_inc);
 	    }
@@ -437,7 +450,7 @@ SnipPipe::done()
 // Check if a non-word character is should be included at the start of the
 // snippet.  We want to include certain leading non-word characters, but not
 // others.
-inline bool
+static inline bool
 snippet_check_leading_nonwordchar(unsigned ch) {
     if (Unicode::is_currency(ch) ||
 	Unicode::get_category(ch) == Unicode::OPEN_PUNCTUATION ||
@@ -466,7 +479,7 @@ snippet_check_leading_nonwordchar(unsigned ch) {
     return false;
 }
 
-inline void
+static inline void
 append_escaping_xml(const char* p, const char* end, string& output)
 {
     while (p != end) {
