@@ -167,20 +167,23 @@ DEFINE_TESTCASE(stubdb2, backend && !inmemory && !remote) {
 #ifdef XAPIAN_HAS_REMOTE_BACKEND
     out.open(dbpath);
     TEST(out.is_open());
-    out << "remote [::1]:80" << endl;
+    out << "remote [::1]:65535" << endl;
     out.close();
 
     try {
 	Xapian::Database db(dbpath, Xapian::DB_BACKEND_STUB);
     } catch (const Xapian::NetworkError& e) {
-	// 1.4.0 threw (Linux):
+	// 1.4.0 threw (on Linux) the confusing message:
 	//  NetworkError: Couldn't resolve host [ (context: remote:tcp([:0)) (No address associated with hostname)
 	// 1.4.1 throws (because we don't actually support IPv6 yet) on Linux (EAI_ADDRFAMILY):
-	//  NetworkError: Couldn't resolve host ::1 (context: remote:tcp(::1:80)) (nodename nor servname provided, or not known)
+	//  NetworkError: Couldn't resolve host ::1 (context: remote:tcp(::1:65535)) (nodename nor servname provided, or not known)
 	// or on OS X (EAI_NONAME):
-	//  NetworkError: Couldn't resolve host ::1 (context: remote:tcp(::1:80)) (Address family for hostname not supported)
-	// So we test the message instead of the error string for portability.
-	TEST(e.get_msg().find("host ::1") != string::npos);
+	//  NetworkError: Couldn't resolve host ::1 (context: remote:tcp(::1:65535)) (Address family for hostname not supported)
+	//
+	// But NetBSD seems to resolve ::1 to an IPv4 address and then tries
+	// to connect to it (which hopefully fails), so just test the message
+	// doesn't match the bad 1.4.0 result.
+	TEST(e.get_msg().find("host [") == string::npos);
     }
 
     try {
@@ -189,11 +192,15 @@ DEFINE_TESTCASE(stubdb2, backend && !inmemory && !remote) {
 	// 1.4.0 threw (Linux):
 	//  NetworkError: Couldn't resolve host [ (context: remote:tcp([:0)) (No address associated with hostname)
 	// 1.4.1 throws (because we don't actually support IPv6 yet) on Linux (EAI_ADDRFAMILY):
-	//  NetworkError: Couldn't resolve host ::1 (context: remote:tcp(::1:80)) (nodename nor servname provided, or not known)
+	//  NetworkError: Couldn't resolve host ::1 (context: remote:tcp(::1:65535)) (nodename nor servname provided, or not known)
 	// or on OS X (EAI_NONAME):
-	//  NetworkError: Couldn't resolve host ::1 (context: remote:tcp(::1:80)) (Address family for hostname not supported)
+	//  NetworkError: Couldn't resolve host ::1 (context: remote:tcp(::1:65535)) (Address family for hostname not supported)
 	// So we test the message instead of the error string for portability.
-	TEST(e.get_msg().find("host ::1") != string::npos);
+	//
+	// But NetBSD seems to resolve ::1 to an IPv4 address and then tries
+	// to connect to it (which hopefully fails), so just test the message
+	// doesn't match the bad 1.4.0 result.
+	TEST(e.get_msg().find("host [") == string::npos);
     }
 #endif
 
@@ -1444,9 +1451,7 @@ DEFINE_TESTCASE(postlist4, backend) {
 // tests long postlists
 DEFINE_TESTCASE(postlist5, backend) {
     Xapian::Database db(get_database("apitest_manydocs"));
-    // Allow for databases which don't support length
-    if (db.get_avlength() != 1)
-	TEST_EQUAL_DOUBLE(db.get_avlength(), 4);
+    TEST_EQUAL_DOUBLE(db.get_avlength(), 4);
     Xapian::PostingIterator i = db.postlist_begin("this");
     unsigned int j = 1;
     while (i != db.postlist_end("this")) {
